@@ -2,14 +2,15 @@
 #    @Author-Email: justincpresley@gmail.com
 #    @Project: NDN State Vector Sync Protocol
 #    @Source-Code: https://github.com/justincpresley/ndn-python-svs
-#    @Pip-Library: https://pypi.org/project/ndn-svs/
+#    @Pip-Library: https://pypi.org/project/ndn-svs
+#    @Documentation: https://ndn-python-svs.readthedocs.io
 
 # Basic Libraries
 from typing import Callable, Optional
 # NDN Imports
 from ndn.app import NDNApp
 from ndn.encoding import Name
-from ndn_python_repo import Storage
+from ndn.storage import Storage
 # Custom Imports
 from .security import SecurityOptions
 from .svs_base import SVSyncBase
