@@ -2,7 +2,8 @@
 #    @Author-Email: justincpresley@gmail.com
 #    @Project: NDN State Vector Sync Protocol
 #    @Source-Code: https://github.com/justincpresley/ndn-python-svs
-#    @Pip-Library: https://pypi.org/project/ndn-svs/
+#    @Pip-Library: https://pypi.org/project/ndn-svs
+#    @Documentation: https://ndn-python-svs.readthedocs.io
 
 # Basic Libraries
 import asyncio as aio
@@ -15,7 +16,7 @@ from ndn.app import NDNApp
 from ndn.encoding import Name
 from ndn.security import Keychain
 from ndn.transport.stream_socket import Face
-from ndn_python_repo import Storage
+from ndn.storage import Storage, DiskStorage
 # Custom Imports
 from .core import SVSyncCore
 from .logger import SVSyncLogger
@@ -41,9 +42,11 @@ class SVSyncBase_Thread(Thread):
     def run(self) -> None:
         def loop_task() -> None:
             self.app = NDNApp(self.face, self.keychain)
+            if issubclass(type(self.storage), DiskStorage):
+                self.storage.initialize()
             try:
                 self.app.run_forever(after_start=self.function())
-            except FileNotFoundError:
+            except (FileNotFoundError, ConnectionRefusedError):
                 print("Error: could not connect to NFD for SVS.")
                 self.failed = True
                 sys.exit()
